@@ -22,8 +22,9 @@ import pytest
         "mkdocstrings.loggers",
         "mkdocstrings.plugin",
         "mkdocstrings.handlers.base",
-        "mkdocstrings.handlers.python",
         "mkdocstrings.handlers.rendering",
+        "mkdocstrings_handlers.python.handler",
+        "mkdocstrings_handlers.python.rendering",
     ],
 )
 @pytest.mark.skipif(sys.version_info < (3, 7), reason="material is not installed on Python 3.6")
@@ -35,6 +36,6 @@ def test_render_themes_templates(module, plugin):
         plugin: The plugin instance (parametrized fixture).
     """
     handler = plugin.handlers.get_handler("python")
-    handler.renderer._update_env(plugin.md, plugin.handlers._config)  # noqa: WPS437
-    data = handler.collector.collect(module, {})
-    handler.renderer.render(data, {})
+    handler._update_env(plugin.md, plugin.handlers._config)  # noqa: WPS437
+    data = handler.collect(module, {})
+    handler.render(data, {})
